==> zio-aws-sagemaker_2.12-5.17.104.13-sources.jar: zio/aws/sagemaker/model/MonitoringConstraintsResource.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.sagemaker.model.primitives.S3Uri
import scala.jdk.CollectionConverters._
final case class MonitoringConstraintsResource(s3Uri: Option[S3Uri] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.MonitoringConstraintsResource = {
    import MonitoringConstraintsResource.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.MonitoringConstraintsResource
      .builder()
      .optionallyWith(
        s3Uri.map(value => S3Uri.unwrap(value): java.lang.String)
      )(_.s3Uri)
      .build()
  }
  def asReadOnly
      : zio.aws.sagemaker.model.MonitoringConstraintsResource.ReadOnly =
    zio.aws.sagemaker.model.MonitoringConstraintsResource.wrap(buildAwsValue())
}
object MonitoringConstraintsResource {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.MonitoringConstraintsResource
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.MonitoringConstraintsResource =
      zio.aws.sagemaker.model
        .MonitoringConstraintsResource(s3Uri.map(value => value))
    def s3Uri: Option[S3Uri]
    def getS3Uri: ZIO[Any, AwsError, S3Uri] =
      AwsError.unwrapOptionField("s3Uri", s3Uri)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.MonitoringConstraintsResource
  ) extends zio.aws.sagemaker.model.MonitoringConstraintsResource.ReadOnly {
    override val s3Uri: Option[S3Uri] = scala
      .Option(impl.s3Uri())
      .map(value => zio.aws.sagemaker.model.primitives.S3Uri(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.MonitoringConstraintsResource
  ): zio.aws.sagemaker.model.MonitoringConstraintsResource.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-sagemaker_2.12-6.20.103.1-sources.jar: zio/aws/sagemaker/model/MonitoringConstraintsResource.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.sagemaker.model.primitives.S3Uri
import scala.jdk.CollectionConverters._
final case class MonitoringConstraintsResource(
    s3Uri: Optional[S3Uri] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.MonitoringConstraintsResource = {
    import MonitoringConstraintsResource.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.MonitoringConstraintsResource
      .builder()
      .optionallyWith(
        s3Uri.map(value => S3Uri.unwrap(value): java.lang.String)
      )(_.s3Uri)
      .build()
  }
  def asReadOnly
      : zio.aws.sagemaker.model.MonitoringConstraintsResource.ReadOnly =
    zio.aws.sagemaker.model.MonitoringConstraintsResource.wrap(buildAwsValue())
}
object MonitoringConstraintsResource {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.MonitoringConstraintsResource
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.MonitoringConstraintsResource =
      zio.aws.sagemaker.model
        .MonitoringConstraintsResource(s3Uri.map(value => value))
    def s3Uri: Optional[S3Uri]
    def getS3Uri: ZIO[Any, AwsError, S3Uri] =
      AwsError.unwrapOptionField("s3Uri", s3Uri)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.MonitoringConstraintsResource
  ) extends zio.aws.sagemaker.model.MonitoringConstraintsResource.ReadOnly {
    override val s3Uri: Optional[S3Uri] = zio.aws.core.internal
      .optionalFromNullable(impl.s3Uri())
      .map(value => zio.aws.sagemaker.model.primitives.S3Uri(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.MonitoringConstraintsResource
  ): zio.aws.sagemaker.model.MonitoringConstraintsResource.ReadOnly =
    new Wrapper(impl)
}
